import { Component, Project } from 'projen';
import { NextTagOptions } from '../types/monotag';
/**
 * Create tasks to support the basics of creating a software release based on git tags.
 * Uses monotag to calculate the next tag and release notes.
 *
 * Tasks:
 *   - release[:name]:current: Verifies if the current commit is already tagged with the latest calculated tag. If so, bumps files, saves version/tag/notes in output files/changelogs.
 *   - release[:name]: Will execute before -> next-tag -> generate -> [tag|push] -> after for this release group
 *   - release[:name]:before: executed before any other tasks in release. Placeholder for any pre-release related tasks
 *   - release[:name]:next-tag: Calculate the next version of the software, output tag and notes to console, write output files, bump files and append changelog. Supports complex release tagging in monorepos by using "npx monotag"
 *   - release[:name]:generate: executed after tag calculation and before git operations. Placeholder for custom tasks, such as doc generation, package build etc
 *   - release[:name]:git-tag: Tag the current commit with the calculated release tag on git repo (if action is 'tag')
 *   - release[:name]:git-push: Push the tagged commit to remote git (if action is 'push')
 *   - release[:name]:after: executed after all other tasks in release. Placeholder for any post-release related tasks
 */
export declare class ReleaseTasks extends Component {
    constructor(project: Project, opts?: ReleaseOptions);
}
export interface ReleaseOptions extends NextTagOptions {
    /**
     * Action to be taken after calculating the next tag
     * Options:
     *  - console: Print calculated tag/notes to console
     *  - tag: Calculate tag/notes, commit and tag (git) resources
     *  - push: Calculate tag/notes, commit, tag (git) and push resources to remote git
     * @default 'console'
     */
    readonly action?: 'console' | 'tag' | 'push';
    /**
     * Name of this release group of tasks
     * Useful if you have multiple release tasks in the same project
     * with different configurations.
     * The release tasks will be named as "release:[name]:[task]"
     * @default ''
     */
    readonly name?: string;
}
